@@ -16,8 +16,8 @@ _ZRAM_SIZE=${_ZRAM_SIZE:-"3G"}
 [[ "${_RUNNING_ARCH}" == "aarch64" ]] && VMLINUZ="Image"
 
 usage () {
-    echo -e "\033[1mUpdate installer, launch latest environment or create latest image files:\033[0m"
-    echo -e "\033[1m-------------------------------------------------------------------------\033[0m"
+    echo -e "\033[1mUpdate installer, launch environments or create latest image files:\033[0m"
+    echo -e "\033[1m-------------------------------------------------------------------\033[0m"
     echo -e "\033[1mPARAMETERS:\033[0m"
     echo -e " \033[1m-u\033[0m               Update scripts: setup, quickinst, tz, km and helpers."
     echo -e ""
@@ -31,6 +31,9 @@ usage () {
     echo -e " \033[1m-latest-image\033[0m    Generate latest image files in /archboot directory"
     echo -e "                  This operation needs at least \033[1m3.5 GB RAM\033[0m."
     echo ""
+    echo -e " \033[1m-launch-xfce\033[0m     Launch XFCE desktop with VNC sharing enabled."
+    echo -e "                  This operation needs at least \033[1m3.2 GB RAM\033[0m."
+    echo ""
     echo -e " \033[1m-h\033[0m               This message."
     exit 0
 }
@@ -48,13 +51,17 @@ _download_latest() {
         echo -e "\033[1mStart:\033[0m Downloading latest km, tz, quickinst, setup and helpers..."
         [[ -d "${_INST}" ]] || mkdir "${_INST}"
         wget -q "${_SOURCE}${_ETC}/defaults?inline=false" -O "${_ETC}/defaults"
-        BINS="quickinst setup km tz copy-mountpoint.sh rsync-backup.sh restore-usbstick.sh \
+        BINS="copy-mountpoint.sh rsync-backup.sh restore-usbstick.sh \
         ${_RUNNING_ARCH}-create-container.sh ${_RUNNING_ARCH}-release.sh \
         binary-check.sh update-installer.sh secureboot-keys.sh mkkeys.sh"
         for i in ${BINS}; do
             [[ -e "${_BIN}/${i}" ]] && wget -q "${_SOURCE}${_BIN}/archboot-${i}?inline=false" -O "${_BIN}/${i}"
             [[ -e "${_BIN}/archboot-${i}" ]] && wget -q "${_SOURCE}${_BIN}/archboot-${i}?inline=false" -O "${_BIN}/archboot-${i}"
         done
+        BINS="quickinst setup km tz"
+        for i in ${BINS}; do
+            [[ -e "${_BIN}/${i}" ]] && wget -q "${_SOURCE}${_BIN}/archboot-${i}.sh?inline=false" -O "${_BIN}/${i}"
+        done
         LIBS="common.sh container.sh release.sh iso.sh update-installer.sh"
         for i in ${LIBS}; do
             wget -q "${_SOURCE}${_LIB}/${i}?inline=false" -O "${_LIB}/${i}"
@@ -138,9 +145,10 @@ _create_container() {
     if [[ -e /var/cache/pacman/pkg/archboot.db ]]; then
         # offline mode, for local image
         # add the db too on reboot
-        install -D -m644 /var/cache/pacman/pkg/archboot.db /archboot/var/cache/pacman/pkg/archboot.db
+        install -D -m644 /var/cache/pacman/pkg/archboot.db "${_W_DIR}"/var/cache/pacman/pkg/archboot.db
         if [[ "${_L_INSTALL_COMPLETE}" == "1" ]]; then
-            "archboot-${_RUNNING_ARCH}-create-container.sh" "${_W_DIR}" -cc --install-source=file:///var/cache/pacman/pkg >/dev/tty7 2>&1 || exit 1
+            mv /var/cache/pacman/pkg/* ${_W_DIR}/var/cache/pacman/pkg/
+            "archboot-${_RUNNING_ARCH}-create-container.sh" "${_W_DIR}" -cc --install-source=file:///${_W_DIR}/var/cache/pacman/pkg >/dev/tty7 2>&1 || exit 1
         fi
     else
         #online mode
@@ -163,11 +171,11 @@ _kver_x86() {
 
 _kver_generic() {
     # get kernel version from installed kernel
-    read _ _ _HWKVER _ < <(grep -m1 -aoE 'Linux version .(\.[-[:alnum:]]+)+' "/${VMLINUZ}")
+    read -r _ _ _HWKVER _ < <(grep -m1 -aoE 'Linux version .(\.[-[:alnum:]]+)+' "/${VMLINUZ}")
 
     # try if the image is gzip compressed
     if [[ -z "${_HWKVER}" ]]; then
-        read _ _ _HWKVER _ < <(gzip -c -d "/${VMLINUZ}" | grep -m1 -aoE 'Linux version .(\.[-[:alnum:]]+)+')
+        read -r _ _ _HWKVER _ < <(gzip -c -d "/${VMLINUZ}" | grep -m1 -aoE 'Linux version .(\.[-[:alnum:]]+)+')
     fi
 
     # fallback if no detectable kernel is installed
@@ -183,7 +191,7 @@ _create_initramfs() {
             fi
         fi
     fi
-    #from /usr/bin/mkinitpcio.conf
+    #from /usr/bin/mkinitcpio.conf
     # compress image with zstd
     cd  "${_W_DIR}"/tmp || exit 1
     find . -mindepth 1 -printf '%P\0' | sort -z |
@@ -222,3 +230,100 @@ _kexec() {
         sleep 1
     done
 }
+
+_launch_xfce() {
+    X_PACKAGES="xorg xfce4 libtiff glib2 chromium libcups gcc-libs glibc harfbuzz avahi nss breeze-icons tigervnc perl p11-kit libp11-kit"
+    if [[ -e /var/cache/pacman/pkg/archboot.db ]]; then
+        echo "Install packages ..."
+        _INSTALL_SOURCE="file:///var/cache/pacman/pkg"
+        _create_pacman_conf
+        #shellcheck disable=SC2086
+        pacman -Sy ${X_PACKAGES} --config ${_PACMAN_CONF} --noconfirm || exit 1
+    else
+        echo "Updating environment ..."
+        pacman -Syu --ignore linux --ignore linux-firmware --noconfirm || exit 1
+        echo "Install packages ..."
+        #shellcheck disable=SC2086
+        pacman -Sy ${X_PACKAGES} --noconfirm || exit 1
+    fi
+    echo "Cleanup archboot environment ..."
+    rm -r /usr/share/{locale,man,info,doc,gtk-doc,ibus}
+    rm -r /usr/include
+    echo "Fix chromium startup ..."
+    # fix chromium startup
+    cat << EOF >/etc/chromium-flags.conf
+--no-sandbox
+--test-type
+wiki.archlinux.org/title/Archboot
+EOF
+    echo "Fix xfce4 defaults ..."
+    # fix xfce4 defaults
+    # breeze icons
+    sed -i -e 's#<property name="IconThemeName" type="string" value="Adwaita"/>#<property name="IconThemeName" type="string" value="breeze"/>#g' \
+    /etc/xdg/xfce4/xfconf/xfce-perchannel-xml/xsettings.xml
+    sed -i -e '/xfce4-run.desktop/i <Filename>archboot.desktop</Filename>' /etc/xdg/menus/xfce-applications.menu
+    sed -i -e 's#firefox#chromium#g' /etc/xdg/xfce4/helpers.rc
+    # background image
+    cat << EOF >/etc/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-desktop.xml
+<?xml version="1.0" encoding="UTF-8"?>
+
+<channel name="xfce4-desktop" version="1.0">
+  <property name="backdrop" type="empty">
+    <property name="screen0" type="empty">
+      <property name="monitor0" type="empty">
+        <property name="image-path" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        <property name="last-single-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        <property name="image-show" type="bool" value="true"/>
+        <property name="image-style" type="int" value="0"/>
+        <property name="workspace0" type="empty">
+          <property name="color-style" type="int" value="0"/>
+          <property name="image-style" type="int" value="3"/>
+          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        </property>
+      </property>
+      <property name="monitorVNC-0" type="empty">
+        <property name="workspace0" type="empty">
+          <property name="color-style" type="int" value="0"/>
+          <property name="image-style" type="int" value="3"/>
+          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        </property>
+      </property>
+      <property name="monitorHDMI1" type="empty">
+        <property name="workspace0" type="empty">
+          <property name="color-style" type="int" value="0"/>
+          <property name="image-style" type="int" value="3"/>
+          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        </property>
+      </property>
+    </property>
+  </property>
+</channel>
+EOF
+    echo "Autostart setup ..."
+    cat << EOF > /etc/xdg/autostart/archboot.desktop
+[Desktop Entry]
+Type=Application
+Name=Archboot Setup
+Exec=xfce4-terminal -x /usr/bin/setup
+Icon=system-software-install
+Categories=X-Xfce-Toplevel;
+EOF
+echo "Set VNC password ..."
+echo 'archboot' | vncpasswd -f > /etc/tigervnc/passwd
+    echo "Autostart tigervnc ..."
+    cat << EOF > /etc/xdg/autostart/tigervnc.desktop
+[Desktop Entry]
+Type=Application
+Name=Tigervnc
+Exec=x0vncserver -rfbauth /etc/tigervnc/passwd
+EOF
+    cp /etc/xdg/autostart/archboot.desktop /usr/share/applications/archboot.desktop
+    echo "Hide menu entries ..."
+    # hide menu entries
+    for i in xfce4-mail-reader qv4l2 qvidcap bssh bvnc avahi-discover fluid; do
+        echo 'NoDisplay=true' >> /usr/share/applications/$i.desktop
+    done
+    echo "Launching XFCE ..."
+    startxfce4
+}
